
/**  // € // to identify files as UTF8
 * managing links used in a site
 *
 * @module          linker
 * @author          Wolfgang Studer
 * @copyright       2017 Wolfgang Studer
 * @link            www.LEPTON-cms.org
 * @license         GNU General Public License
 * @license_terms   please see info.php of this module
 * @version         $Id: 1.08.000 | 2017-12-30
 * @lepador_link    http://www.lepton-cms.com/lepador/admintools/linker.php
 * @forum_link      http://forum.lepton-cms.org/viewtopic.php?f=66&t=3053
*/


var linker_STARTCOLLAPSED = { group:0, link:0 };

$(document).ready(function()
{
	/*
	 * start table collapse
	 */
	$('.linkergroup').aCollapTable({
		  startCollapsed: linker_STARTCOLLAPSED.group
		, addColumn: false
		, plusButton: '<img class="i" src="' + THEME_URL + '/images/plus_16.png" />'
		, minusButton: '<img class="i" src="' + THEME_URL + '/images/minus_16.png" />'
	});
	$('.linkerlink').aCollapTable({
		  startCollapsed: linker_STARTCOLLAPSED.link
		, addColumn: false
		, plusButton: '<img class="i" src="' + THEME_URL + '/images/plus_16.png" />'
		, minusButton: '<img class="i" src="' + THEME_URL + '/images/minus_16.png" />'
	});

	/*
	 * valid from/till datepicker
	 */
	$.datepicker.setDefaults(
	{
		  showOtherMonths: true
		, selectOtherMonths: true
		, showWeek: true
		, firstDay: 1
		, dateFormat: DATE_FORMAT
		, autoSize: true
	});
	$( '.datepicker' ).datepicker();

});

/*
 * update version if a change has been made
 */
function linker_row_changed( change_id, language )
{
	// update version field to -1
	$( '#version_' + change_id ).val('-1');

	// update language version field if present
	if ( language )
	{
		$( '#version_' + language + '_' + change_id ).val('-1');
	}

	// add class to modifier cell
	$( '#modifier_' + change_id ).addClass( 'modified' );

};

/*
 * set module specific additional flags
 */
function linker_delete_row_set_flag( row_id, data )
{
	// set new image attributes for status image
	var data_source = data.data.status_src;
	var data_alt = data.data.status_alt;
	var data_title = data.data.status_title;
	$( '#img_status_' + row_id ).attr( 'src', data_source );
	$( '#img_status_' + row_id ).attr( 'alt', data_alt );
	$( '#img_status_' + row_id ).attr( 'title', data_title );

	// set new image attributes for confirmation image
	var data_source = data.data.confirm_src;
	var data_alt = data.data.confirm_alt;
	var data_title = data.data.confirm_title;
	$( '#img_confirm_' + row_id ).attr( 'src', data_source );
	$( '#img_confirm_' + row_id ).attr( 'alt', data_alt );
	$( '#img_confirm_' + row_id ).attr( 'title', data_title );
};

/*
 * validate group by checking of duplication in add_group
 */
function linker_validate( action, dialogTitle )
{
	// init return
	var ret = true;

	// ajax call to set flag and return info box
	var url = LEPTON_URL+'/modules/linker/ajax.validate.php';
	var postdata = {
		action: action
	}

	var fieldIds = [];
	if ( action == 'addgroup' )
	{
		fieldIds = [ 'group_name', 'leptoken' ];
	}
	fieldIds.forEach(function (s, i, o)
	{
		postdata[s] = document.getElementById( s ).value;
	});

	$.ajax({
		url: url
		, type: 'post'
		, dataType: 'json'
		, data: postdata
		, success: function ( data )
			{
				// handle active flag returned
				if( data.status == -1 )
				{
					// create the dialog with default options
					linker_show_dialog( dialogTitle, data.ResponseText );

					ret = false;
				}
			}
	});

	return ret;
};


/*
 * add a new link row set
 */
function linker_add_row( link_id, add_rows )
{
	// get number of rows in table "links"
	var row_counts = $('.linkerlink tr#trlinks').length;
	
	// ajax call to set flag and return info box
	var url = LEPTON_URL+'/modules/linker/ajax.add_link.php';
	var postdata = {
		action: 'add_link'
		, link_id: link_id
		, row_counts: row_counts
		, add_rows: add_rows
	}

	var fieldIds = [ 'leptoken' ];
	fieldIds.forEach(function (s, i, o)
	{
		postdata[s] = document.getElementById( s ).value;
	});

	$.ajax({
		url: url
		, type: 'post'
		, dataType: 'json'
		, data: postdata
		, success: function ( data )
			{
			$('.linkerlink').append( data.ResponseText );
			}
	});
};


/*
 * process link type change
 */
function linker_change_link_type( link_id, lang_cd )
{
	// clear the involved fields
	$( '.link_url_'         + link_id ).val('');
	$( '.link_type_main_'   + link_id ).val('');
	$( '.link_type_main_'   + link_id ).empty();
	$( '.link_type_detail_' + link_id ).val('');
	$( '.link_type_detail_' + link_id ).empty();

	// remove required
	$( '.link_type_main_'   + link_id ).prop( 'required', false );
	$( '.link_type_detail_' + link_id ).prop( 'required', false );

	// hide all the involved fields
	$( '.link_url_'             + link_id ).removeClass( 'hidden' );
	$( '.link_url_add_'         + link_id ).removeClass( 'hidden' );
	$( '.link_type_main_'       + link_id ).removeClass( 'hidden' );
	$( '.link_type_detail_'     + link_id ).removeClass( 'hidden' );
	$( '.link_type_detail_add_' + link_id ).removeClass( 'hidden' );
	$( '.link_url_'             + link_id ).addClass( 'hidden' );
	$( '.link_url_add_'         + link_id ).addClass( 'hidden' );
	$( '.link_type_main_'       + link_id ).addClass( 'hidden' );
	$( '.link_type_detail_'     + link_id ).addClass( 'hidden' );
	$( '.link_type_detail_add_' + link_id ).addClass( 'hidden' );

	// get selected link_type value
	var action = $( '#link_type_' + link_id ).val();
	
	// show link_url for type link. No further actions needed
	if ( action == 'link' )
	{
		$( '.link_url_'       + link_id ).removeClass( 'hidden' );
		$( '.link_url_add_'   + link_id ).removeClass( 'hidden' );
		return;
	}
	else if ( action == 'page' )
	{
		action = 'page_tree';
	}
	else if ( action == 'media' )
	{
		action = 'folder_tree';
	}

	// show link details with dummy values
	$( '.link_type_main_'       + link_id ).removeClass( 'hidden' );
	$( '.link_type_detail_'     + link_id ).removeClass( 'hidden' );
	$( '.link_type_detail_add_' + link_id ).removeClass( 'hidden' );

	$( '.link_type_main_'     + link_id ).append(
		$('<option>', { value : '' }).text('...')
	);
	$( '.link_type_detail_'     + link_id ).append(
		$('<option>', { value : '' }).text('...')
	);

	// ajax call to get contents
	var url = LEPTON_URL+'/modules/linker/ajax.select_details.php';
	var postdata = {
		action: action
		, row_key: linker_ROWKEY
		, row_id: link_id
	}

	var fieldIds = [ 'leptoken' ];
	fieldIds.forEach(function (s, i, o)
	{
		postdata[s] = document.getElementById( s ).value;
	});

	$.ajax({
		url: url
		, type: 'post'
		, dataType: 'json'
		, data: postdata
		, success: function ( data )
		{
			var dataParent = data.data.PARENT;
			var dataChild  = data.data.CHILD;

			$( '.link_type_main_'   + link_id ).val('');
			$( '.link_type_main_'   + link_id ).empty();
			$.each( dataParent, function( key, value )
			{
				if ( key == '0' ) { key = ''; }

				$( '.link_type_main_' + link_id ).append(
					$('<option>', { value : key }).text(value)
				);
			});
			$( '.link_type_detail_' + link_id ).val('');
			$( '.link_type_detail_' + link_id ).empty();
			$.each( dataChild, function( key, value )
			{
				if ( key == '0' ) { key = ''; }

				$( '.link_type_detail_' + link_id ).append(
					$('<option>', { value : key }).text(value)
				);
			});
		}
	});
};


/*
 * process link main field change as a wrapper
 */
function linker_change_link_type_main( link_id, lang_cd )
{
	// get selected link_type value
	var link_type = $( '#link_type_' + link_id ).val();

	// set action
	var action = '';
	if ( link_type == 'page' )	{ action = 'section_list'; }
	else						{ action = 'file_list'; }

	// define targets
	var targetMain   = 'link_type_main_'   + lang_cd + link_id;
	var targetDetail = 'link_type_detail_' + lang_cd + link_id;

	// get selected main value
	var mainValue = $( '#' + targetMain ).val();
	if ( mainValue == '' )
	{
		// clear target
		$( '#' + targetDetail ).val('');
		$( '#' + targetDetail ).empty();
		// remove required on target
		$( '#' + targetDetail ).prop( 'required', false );
		// show dummy value in target
		$( '#' + targetDetail ).append(
			$('<option>', { value : '' }).text('...')
		);

		return;
	}

	// is field required
	var required = 0;
	if ( link_type == 'media' )	{ required = 1; }

	// call the generic function
	linker_select_details( action, link_id, targetMain, targetDetail, required );
};


/*
 * show status in dialog
 */
function linker_show_status( link_id, dialogTitle )
{
	// image title is text to be shown
	var dialogText = $( '#img_status_' + link_id ).attr( 'title' );

	// show dialog
	linker_show_dialog( dialogTitle, dialogText );
}


/*
 * confirm the link
 */
function linker_confirm_link( link_id, dialogTitle, confirmText )
{
	// Do you confirm
	if ( ! confirm( confirmText ) )
	{
		return;
	}

	// ajax call to set confirmation when & by and recalculated status
	var url = LEPTON_URL+'/modules/linker/ajax.confirm_link.php';
	var postdata = {
		action: 'confirm'
		, link_id: link_id
	}
	var fieldIds = [ 'leptoken' ];
	fieldIds.forEach(function (s, i, o)
	{
		postdata[s] = document.getElementById( s ).value;
	});

	$.ajax({
		url: url
		, type: 'post'
		, dataType: 'json'
		, data: postdata
		, success: function ( data )
			{
				// set new image attributes for status image
				var data_source = data.data.status_src;
				var data_alt = data.data.status_alt;
				var data_title = data.data.status_title;
				$( '#img_status_' + link_id ).attr( 'src', data_source );
				$( '#img_status_' + link_id ).attr( 'alt', data_alt );
				$( '#img_status_' + link_id ).attr( 'title', data_title );

				// set new image attributes for confirmation image
				var data_source = data.data.confirm_src;
				var data_alt = data.data.confirm_alt;
				var data_title = data.data.confirm_title;
				$( '#img_confirm_' + link_id ).attr( 'src', data_source );
				$( '#img_confirm_' + link_id ).attr( 'alt', data_alt );
				$( '#img_confirm_' + link_id ).attr( 'title', data_title );

				// set new last_confirmed_when & by
				var val = data.data.last_confirmed_when;
				document.getElementById( 'last_confirmed_when_' + link_id ).innerHTML = val;
				val = data.data.last_confirmed_by_name;
				document.getElementById( 'last_confirmed_by_' + link_id ).innerHTML = val;

				// create the dialog with default options
				linker_show_dialog( dialogTitle, data.ResponseText );

				// add timeout event to automatically close the dialog after 2 seconds
				var data_status = data.data.status;
				if ( data_status == 'OK' )
				{
					linker_close_on_timeout( 1, 2 );
				}
			}
	});
};


/*
 * open link on click in new window/tab
 */
function linker_open_link( key )
{
	var linkUrl = document.getElementById( key ).value;
	var redirectWindow = window.open( linkUrl, '_blank' );
	redirectWindow.location;
};
