<?php

/**  // € // to identify files as UTF8
 * managing links used in a site
 *
 * @module          linker
 * @author          Wolfgang Studer
 * @copyright       2017 Wolfgang Studer
 * @link            www.LEPTON-cms.org
 * @license         GNU General Public License
 * @license_terms   please see info.php of this module
 * @version         $Id: 1.08.000 | 2017-12-30
 * @lepador_link    http://www.lepton-cms.com/lepador/admintools/linker.php
 * @forum_link      http://forum.lepton-cms.org/viewtopic.php?f=66&t=3053
*/


// include class.secure.php to protect this file and the whole CMS!
	if ( defined('LEPTON_PATH') == TRUE ):
		include(LEPTON_PATH.'/framework/class.secure.php');
	else:
		$oneback = "../";
		$root = $oneback;
		$level = 1;
		while (( $level < 10 ) && ( file_exists( $root . '/framework/class.secure.php' ) == FALSE )):
			$root .= $oneback;
			$level += 1;
		endwhile;
	
		if ( file_exists($root.'/framework/class.secure.php') == TRUE ):
			include( $root . '/framework/class.secure.php' );
		else:
			trigger_error( sprintf("[ <b>%s</b> ] Can't include class.secure.php!", $_SERVER['SCRIPT_NAME']), E_USER_ERROR );
		endif;
	endif;
// end include class.secure.php


/** ------------------------------------------------------------------------------------
 * build text array
 * @return	array		text array
 * @param	array		$link		= datalist of related link
 * @param	string		$query to be executed
 * @param	array		$fields 	= list of fields to be set in aray per language
 * @param	array		$languages	= list of available languages
 * @param	string		$langKey	= name of language code field
 ** ------------------------------------------------------------------------------------
 */
if ( function_exists( 'linker_build_text_array' ) == FALSE ):
	function linker_build_text_array( $link = array(), $query = '', $fields = array(), $languages = array(), $langKey = 'language' )
	{
		// initialize return array
		$text = array();
		foreach ( $languages as $language ):
			foreach ( $fields as $field ):
				$text[ $language ][ $field ] = '';
				if ( $field == 'is_DB' ):
					$text[ $language ][ $field ] = 0;
				endif;
			endforeach;
		endforeach;

		// is query string
		if ( strlen( trim( $query )) == 0 ):
			return linker_finalize_text_array( $link, $text );
		endif;

		// get text
		$tmp = linker_execute_query( __FUNCTION__, $query, 'get_all' );

		// no data found
		if ( count( $tmp ) == 0 ):
			return linker_finalize_text_array( $link, $text );
		endif;

		// loop over query array received and rebuild
		foreach ( $tmp as $index => $items ):
			if ( array_key_exists( $langKey, $items ) == TRUE ):
				$language = $items[ $langKey ];
			else:
				$language = LANGUAGE;
			endif;

			foreach ( $items as $field => $value ):
				if (( array_key_exists( $language, $text )			 == TRUE )
				and ( array_key_exists( $field, $text[ $language ] ) == TRUE )):
					$text[ $language ][ $field ] = $value;
				endif;
			endforeach;
		endforeach;

		// return
		return linker_finalize_text_array( $link, $text );
	}
endif;

/** ------------------------------------------------------------------------------------
 * finalize text array
 * @return	array		text array
 * @param	array		$link		= datalist of related link
 * @param	array		$text 		= list of text items evaluated so far
 ** ------------------------------------------------------------------------------------
 */
if ( function_exists( 'linker_finalize_text_array' ) == FALSE ):
	function linker_finalize_text_array( $link, $text )
	{
		// processing link_type if needed
		unset( $tmp );
		switch ( $link[ 'link_type' ] ):
		case 'page':
		case 'media':
			// loop over text items
			foreach ( $text as $language => &$tmp ):
				// set dummy fields to refered page id and section
				$link_type_main = '';
				$link_type_detail = '';
				linker_init_link_type( $link[ 'link_type' ], $tmp['link_ext' ], $language, $link_type_main, $link_type_detail );
				$tmp[ 'link_type_main' ]	= $link_type_main;
				$tmp[ 'link_type_detail' ]	= $link_type_detail;
			endforeach;
			break;
		endswitch;

		// return
		return( $text );
	}
endif;

?>
