<?php

/**  // € // to identify files as UTF8
 * managing links used in a site
 *
 * @module          linker
 * @author          Wolfgang Studer
 * @copyright       2017 Wolfgang Studer
 * @link            www.LEPTON-cms.org
 * @license         GNU General Public License
 * @license_terms   please see info.php of this module
 * @version         $Id: 1.08.000 | 2017-12-30
 * @lepador_link    http://www.lepton-cms.com/lepador/admintools/linker.php
 * @forum_link      http://forum.lepton-cms.org/viewtopic.php?f=66&t=3053
*/


// include class.secure.php to protect this file and the whole CMS!
	if ( defined('LEPTON_PATH') == TRUE ):
		include(LEPTON_PATH.'/framework/class.secure.php');
	else:
		$oneback = "../";
		$root = $oneback;
		$level = 1;
		while (( $level < 10 ) && ( file_exists( $root . '/framework/class.secure.php' ) == FALSE )):
			$root .= $oneback;
			$level += 1;
		endwhile;
	
		if ( file_exists($root.'/framework/class.secure.php') == TRUE ):
			include( $root . '/framework/class.secure.php' );
		else:
			trigger_error( sprintf("[ <b>%s</b> ] Can't include class.secure.php!", $_SERVER['SCRIPT_NAME']), E_USER_ERROR );
		endif;
	endif;
// end include class.secure.php


/** ------------------------------------------------------------------------------------
 * initialize link type fields and values
 * @return	string		&$link_type_main, as reference
 * @return	string		&$link_type_detail, as reference
 * @param	string		$link_type			= link type to be tested
 * @param	string		$link_source		= source value
 * @param	string		$language			= '' or text language
 * @param	string		&$link_type_main	= set for return
 * @param	string		&$link_type_detail	= set for return
 ** ------------------------------------------------------------------------------------
 */
if ( function_exists( 'linker_init_link_type' ) == FALSE ):
	function linker_init_link_type( $link_type = 'link', $link_source = '', $language = '', &$link_type_main = '', &$link_type_detail = '' )
	{
		// define globals
		global $pageTree;
		global $pageTreeSections;
		global $folderTree;
		global $folderTreeFiles;
		global $linker_treekind;
		global $linker_disabledModules;
		global $linker_modulePath;
		global $linker_languages;
		global $MOD_LINKER;

		// init return values
		$link_type_main   = '';
		$link_type_detail = '';

		// processing link_type if needed
		switch ( $link_type ):
		case 'link':
			// no specific action is needed
			break;

		case 'page':
			// build page tree if needed
			if ( count( $pageTree ) == 0 ):

				$action = 'page_tree';
				$selectParams = array();

				// call the library handle the action
				$file = $linker_modulePath
						. 'lib' . DIRECTORY_SEPARATOR
						. 'lib.data.ajax.select_details.php';
				if ( is_file ( $file ) == TRUE ):
					$sectionList = array();
					include( $file );

					// returns
					// * $pageTree = array of pages
					// * $sectionList = array with section_list/mainselect text entry if exists

					// the first pageTree item might be returned with key = 0 in order to keep
					// sequence when handled via ajax with javascript
					if ( array_key_exists( '0', $pageTree ) == TRUE ):
						$tmp = array();
						$tmp[''] = $pageTree['0'];
						unset( $pageTree['0'] );
						$pageTree = $tmp + $pageTree;
					endif;

					$link_type_detail = $sectionList[0];
				endif;
			endif;

			// set dummy fields to refered page id and section
			if ( strlen( trim( $link_source )) > 0 ):
				$arr = explode( ',', $link_source );
				if ( count( $arr ) > 0 ):
					$link_type_main   = trim( $arr[0] );
					$link_type_detail = '';
					if ( count( $arr ) > 1 ):
						$link_type_detail = trim( $arr[1] );
					endif;
				endif;
			endif;

			// build section list for given page if not already available
			if (( strlen( $link_type_main ) > 0 )
			and ( array_key_exists( $link_type_main, $pageTreeSections ) == FALSE )):

				$action = 'section_list';
				$selectParams = array();
				$selectParams[ 'page_id' ] = $link_type_main;

				// check if a dedicated action lib script exists
				$file = $linker_modulePath
						. 'lib' . DIRECTORY_SEPARATOR
						. 'lib.data.ajax.select_details.php';
				if ( is_file ( $file ) == TRUE ):
					$sectionList = array();
					include( $file );

					// returns
					// * $sectionList = array with section_list/mainselect text entry if exists

					// the first sectionList item might be returned with key = 0 in order to keep
					// sequence when handled via ajax with javascript
					if ( array_key_exists( '0', $sectionList ) == TRUE ):
						$tmp = array();
						$tmp[''] = $sectionList['0'];
						unset( $sectionList['0'] );
						$sectionList = $tmp + $sectionList;
					endif;

					$pageTreeSections[ $link_type_main ] = $sectionList;
				endif;
			endif;

			break;


		case 'media':
			// build folder tree if needed
			if ( count( $folderTree ) == 0 ):

				$action = 'folder_tree';
				$selectParams = array();

				// check if a dedicated action lib script exists
				$file = $linker_modulePath
						. 'lib' . DIRECTORY_SEPARATOR
						. 'lib.data.ajax.select_details.php';
				if ( is_file ( $file ) == TRUE ):
					$fileList = array();
					include( $file );

					// returns
					// * $folderTree = array of folders within root
					// * $fileList = array with file_list/mainselect text entry if exists

					// the first folderTree item might be returned with key = 0 in order to keep
					// sequence when handled via ajax with javascript
					if ( array_key_exists( '0', $folderTree ) == TRUE ):
						$tmp = array();
						$tmp[''] = $folderTree['0'];
						unset( $folderTree['0'] );
						$folderTree = $tmp + $folderTree;
					endif;

					$link_type_detail = $fileList[0];
				endif;
			endif;

			// set dummy fields to refered folder & file
			if ( strlen( trim( $link_source )) > 0 ):
				$arr = pathinfo( $link_source );
				$link_type_main   = $arr['dirname'];
				if ( $link_type_main != DIRECTORY_SEPARATOR ):
					$link_type_main .= DIRECTORY_SEPARATOR;
				endif;
				$link_type_detail = $arr['basename'];
			endif;

			// build files list for given folder
			if (( strlen( $link_type_main ) > 0 )
			and ( array_key_exists( $link_type_main, $folderTreeFiles ) == FALSE )):

				$action = 'file_list';
				$selectParams = array();
				$selectParams[ 'root' ] = LEPTON_PATH . DIRECTORY_SEPARATOR . MEDIA_DIRECTORY . $link_type_main . DIRECTORY_SEPARATOR;

				// check if a dedicated action lib script exists
				$file = $linker_modulePath
						. 'lib' . DIRECTORY_SEPARATOR
						. 'lib.data.ajax.select_details.php';
				if ( is_file ( $file ) == TRUE ):
					$fileList = array();
					include( $file );

					// returns
					// * $fileList = array with files inside given root folder

					// the first fileList item might be returned with key = 0 in order to keep
					// sequence when handled via ajax with javascript
					if ( array_key_exists( '0', $fileList ) == TRUE ):
						$tmp = array();
						$tmp[''] = $fileList['0'];
						unset( $fileList['0'] );
						$fileList = $tmp + $fileList;
					endif;

					$folderTreeFiles[ $link_type_main ] = $fileList;
				endif;
			endif;

			break;
		endswitch;

	}
endif;

?>
