<?php

/**  // € // to identify files as UTF8
 * managing links used in a site
 *
 * @module          linker
 * @author          Wolfgang Studer
 * @copyright       2017 Wolfgang Studer
 * @link            www.LEPTON-cms.org
 * @license         GNU General Public License
 * @license_terms   please see info.php of this module
 * @version         $Id: 1.08.000 | 2017-12-30
 * @lepador_link    http://www.lepton-cms.com/lepador/admintools/linker.php
 * @forum_link      http://forum.lepton-cms.org/viewtopic.php?f=66&t=3053
*/


// include class.secure.php to protect this file and the whole CMS!
	if ( defined('LEPTON_PATH') == TRUE ):
		include(LEPTON_PATH.'/framework/class.secure.php');
	else:
		$oneback = "../";
		$root = $oneback;
		$level = 1;
		while (( $level < 10 ) && ( file_exists( $root . '/framework/class.secure.php' ) == FALSE )):
			$root .= $oneback;
			$level += 1;
		endwhile;
	
		if ( file_exists($root.'/framework/class.secure.php') == TRUE ):
			include( $root . '/framework/class.secure.php' );
		else:
			trigger_error( sprintf("[ <b>%s</b> ] Can't include class.secure.php!", $_SERVER['SCRIPT_NAME']), E_USER_ERROR );
		endif;
	endif;
// end include class.secure.php


/** ------------------------------------------------------------------------------------
 * build folder tree
 * @return	array		$list		= result
 * @param	string		$root		= root folder to get files from
 * @param	array		$list		= available result so far
 * @param	string		$keyPrefix	= prefix string to be added before the tree key (= file name)
 * @param	array		$linker_vars
 ** ------------------------------------------------------------------------------------
 */
if ( function_exists( 'linker_build_file_list' ) == FALSE ):
	function linker_build_file_list( $root = '', $list = array(), $keyPrefix = '', $linker_vars = array() )
	{
		// input root folder missing
		if ( strlen( trim( $root )) == 0 ):
			return( linker_finalize_file_list( $root, $list, $linker_vars ) );
		endif;

		// input root folder does not exists
		if ( is_dir( $root ) == FALSE ):
			return( linker_finalize_file_list( $root, $list, $linker_vars ) );
		endif;

		// getting all files (files only) from $root
		foreach ( array_filter( glob( $root . '*' ), 'is_file' ) as $file ):
			// remove root folder from file name
			$file = str_replace( $root, '', $file);

			// ignore index.php in media folders
			if ( strtolower( $file ) == 'index.php' ):
				continue;
			endif;

			// use specific layout if needed
			linker_get_file_layout( $root, $file, $linker_vars );

			// prepare list
			$list[ $keyPrefix . $file ] = $file;
		endforeach;

		// return the tree
		return( linker_finalize_file_list( $root, $list, $linker_vars ) );
	}
endif;


/** ------------------------------------------------------------------------------------
 * complete filelist
 * @return	array		$list
 * @param	string		$root		= root folder to get files from
 * @param	array		$list
 * @param	array		$linker_vars
 ** ------------------------------------------------------------------------------------
 */
if ( function_exists( 'linker_finalize_file_list' ) == FALSE ):
	function linker_finalize_file_list( $root, $list, $linker_vars )
	{
		// overwrite globals with passed vars
		// needed in frontend when some vars are not properly handled by global
		if (( count( $linker_vars ) > 0 )
		and ( array_key_exists( 'MOD_LINKER', $linker_vars ) == TRUE )):
			$MOD_LINKER = $linker_vars[ 'MOD_LINKER' ];
		endif;

		// init return
		$result = array();

		// data available
		if (( count( $list ) > 0 )
		and ( array_key_exists( 'file', $MOD_LINKER ) == TRUE )):
			// !! Do not use array_merge as it does not preserve numeric key values
			// which might be the case if keyPrefix is '' !!!
			$result = array( '0' => $MOD_LINKER['file'] ) + $list;
		elseif (( strlen( trim( $root )) == 0 )
			and ( array_key_exists( 'mainselect', $MOD_LINKER ) == TRUE )):
			$result[''] = $MOD_LINKER['mainselect'];
		elseif ( array_key_exists( 'nofile', $MOD_LINKER ) == TRUE ):
			$result[''] = $MOD_LINKER['nofile'];
		endif;

		// return the tree
		return($result);
	}
endif;


/** ------------------------------------------------------------------------------------
 * set layout for section line
 * @return	array		&$file as reference
 * @param	array		$root
 * @param	array		$file
 * @param	array		$linker_vars
 *
 * Note: This is done in a separate function in order that just this function can be replaced if wanted
 ** ------------------------------------------------------------------------------------
 */
if ( function_exists( 'linker_get_file_layout' ) == FALSE ):
	function linker_get_file_layout( $root, &$file, $linker_vars )
	{
		// update $file if needed
	}
endif;

?>
