<?php

/**  // € // to identify files as UTF8
 * managing links used in a site
 *
 * @module          linker
 * @author          Wolfgang Studer
 * @copyright       2017 Wolfgang Studer
 * @link            www.LEPTON-cms.org
 * @license         GNU General Public License
 * @license_terms   please see info.php of this module
 * @version         $Id: 1.08.000 | 2017-12-30
 * @lepador_link    http://www.lepton-cms.com/lepador/admintools/linker.php
 * @forum_link      http://forum.lepton-cms.org/viewtopic.php?f=66&t=3053
*/


// include class.secure.php to protect this file and the whole CMS!
	if ( defined('LEPTON_PATH') == TRUE ):
		include(LEPTON_PATH.'/framework/class.secure.php');
	else:
		$oneback = "../";
		$root = $oneback;
		$level = 1;
		while (( $level < 10 ) && ( file_exists( $root . '/framework/class.secure.php' ) == FALSE )):
			$root .= $oneback;
			$level += 1;
		endwhile;
	
		if ( file_exists($root.'/framework/class.secure.php') == TRUE ):
			include( $root . '/framework/class.secure.php' );
		else:
			trigger_error( sprintf("[ <b>%s</b> ] Can't include class.secure.php!", $_SERVER['SCRIPT_NAME']), E_USER_ERROR );
		endif;
	endif;
// end include class.secure.php


// admin must be set
	if (( isset($admin)			== FALSE )
	or  ( is_object( $admin )	== FALSE )):
		die();
	endif;

// check input
	$inputs = array();
	$inputs[ 'kind' ]			= array( 'filter' => FILTER_SANITIZE_STRING, 'default' => 'list', 'allowed' => array( 'save', 'list' ) );
	$inputs[ 'action' ]			= array( 'filter' => FILTER_SANITIZE_STRING, 'allowed' => array( 'addgroup', 'settings', 'links' ) );
	$inputs[ 'group_name' ]		= array( 'filter' => FILTER_SANITIZE_STRING );
	$inputs[ 'link_id' ]		= array( 'filter' => FILTER_SANITIZE_NUMBER_INT, 'default' => 0 );
	$inputs[ 'leptoken' ]		= array( 'filter' => FILTER_SANITIZE_STRING );
	$inputs[ 'return_target' ]	= array( 'filter' => FILTER_SANITIZE_STRING );
	$inputs[ 'return_anchor' ]	= array( 'filter' => FILTER_SANITIZE_STRING );

// Get input parameter values
	// handle first the link data
	if ( array_key_exists( 'LINK', $_POST ) == TRUE ):
		$inputs[ 'LINK' ] = array( 'kind' => 'array' );

		foreach ( $_POST[ 'LINK' ] as $linkId => $linkItems ):
			foreach ( $linkItems as $key => $value ):
				switch ( $key ):
				case 'parent':
				case 'active':
				case 'position':
				case 'is_DB':
				case 'version':
				case 'confirmation_age_warning':
				case 'confirmation_age_endvalid':
					$inputs[ 'LINK' ][ $linkId ][ $key ] = array( 'filter' => FILTER_SANITIZE_NUMBER_INT );
					break;
				case 'link_url':
				case 'group_collection':
				case 'group_name':
				case 'link_code':
				case 'link_type':
				case 'link_type_main':
				case 'link_type_detail':
				case 'valid_from':
				case 'valid_till':
				case 'visibility':
				case 'release_code':
					$inputs[ 'LINK' ][ $linkId ][ $key ] = array( 'filter' => FILTER_SANITIZE_STRING );
					break;
				endswitch;
			endforeach;
		endforeach;
		unset( $linkId );
		unset( $linkItems );
	endif;
	// handle then the text data
	if ( array_key_exists( 'TEXT', $_POST ) == TRUE ):
		$inputs[ 'TEXT' ] = array( 'kind' => 'array' );

		foreach ( $_POST[ 'TEXT' ] as $linkId => $linkItems ):
			foreach ( $linkItems as $key => $value ):
				$tmp = explode( '-', $key, 2 );
				switch ( $tmp[1] ):
				case 'is_DB':
				case 'version':
					$inputs[ 'TEXT' ][ $linkId ][ $key ] = array( 'filter' => FILTER_SANITIZE_NUMBER_INT );
					break;
				case 'link_title':
				case 'link_desc':
				case 'link_ext':
				case 'link_type_main':
				case 'link_type_detail':
					$inputs[ 'TEXT' ][ $linkId ][ $key ] = array( 'filter' => FILTER_SANITIZE_STRING );
				endswitch;
			endforeach;
		endforeach;
		unset( $linkId );
		unset( $linkItems );
	endif;

// set $module as current module
	$linker_module = 'linker';

// set processing initials
	unset( $twigTemplate );
	$linker_component = basename( __FILE__, '.php' );
	$linker_modulePath = dirname( __FILE__ ) . DIRECTORY_SEPARATOR;
	$includes = array();

// include the basic files at start
	// setup module initials
	$includes[]	= array( 'LOADER'=> 'require', 'FILE' => $linker_modulePath . 'register_initial.php' );
	include( $linker_modulePath . 'load_includes.php' );

	// include language registration
	$includes[]	= $linker_modulePath . 'register_language.php';
	// include backend config files
	$includes[]	= $linker_modulePath . 'lib/lib.config.php';
	$includes[]	= $linker_modulePath . 'lib/lib.backend.config.php';
	$includes[]	= $linker_templatePath . 'lib/lib.backend.config.php';
	$includes[]	= $linker_modulePath . 'lib/lib.backend.config.' . $linker_component . '.php';
	$includes[]	= $linker_templatePath . 'lib/lib.backend.config.' . $linker_component . '.php';
	// include basic functions
	$includes[]	= $linker_templatePath . 'lib/lib.backend.functions.' . $linker_component . '.php';
	$includes[]	= $linker_templatePath . 'lib/lib.backend.functions.php';
	$includes[]	= $linker_modulePath . 'lib/lib.backend.functions.' . $linker_component . '.php';
	$includes[]	= $linker_modulePath . 'lib/lib.backend.functions.php';
	// do include
	include( $linker_modulePath . 'load_includes.php' );

	// initialize data variable
	$data = array();

	// do input validation
	if ( $_SERVER["REQUEST_METHOD"] == 'POST' ):
		$error = linker_input_filter( 'POST', $_POST, $inputs );
	else:
		$error = linker_input_filter( 'GET', $_GET, $inputs );
	endif;
	$linker_status = '';
	if ( $error != 0 ):
		$status = FALSE;
		$linker_status = $MOD_LINKER['ERROR']['INPUT'] . ' [ ' . $error . ' ]' . '<br />' . $inputs[$error][ 'error' ];
		unset( $inputs );

	else:
		// save input into local vars
		$kind			= $inputs[ 'kind' ][ 'value' ];
		$action			= $inputs[ 'action' ][ 'value' ];
		$group_name		= $inputs[ 'group_name' ][ 'value' ];
		$link_id		= $inputs[ 'link_id' ][ 'value' ];
		$leptoken		= $inputs[ 'leptoken' ][ 'value' ];
		$return_target	= $inputs[ 'return_target' ][ 'value' ];
		$return_anchor	= $inputs[ 'return_anchor' ][ 'value' ];

		$data = array();
		foreach ( array( 'LINK', 'TEXT' ) as $type ):
			if ( array_key_exists( $type, $inputs ) == TRUE ):
				foreach ( $inputs[ $type ] as $id => $idset ):
					foreach ( $idset as $key => $value ):
						if (( array_key_exists( 'value', $value ) == TRUE )
						and ( strlen( trim( $value[ 'value' ] ))  >  0    )):
							$data[ $type ][ $id ][ $key ] = $value[ 'value' ];
						endif;
					endforeach;
				endforeach;
			endif;
		endforeach;

		unset( $inputs );

		// update component variable
			// handle kind
		if ( $kind == 'save' ):
			$linker_component .= '_' . $kind;
		endif;
			// handle action
		if ( strlen( trim( $action )) > 0 ):
			$linker_component .= '_' . $action;
		endif;

		// initialize return status
		$status = TRUE;
		$show_success = TRUE;
		if ( strlen( $return_target ) == 0 ):
			$return_target = ADMIN_URL . DIRECTORY_SEPARATOR . 'admintools' . DIRECTORY_SEPARATOR . 'tool.php?tool=linker';
		endif;

		if ( $kind == 'save' ):
			// save data processing
			$includes[]	= $linker_modulePath . '/lib/lib.save.' . $linker_component . '.php';
			$includes[]	= array( 'LOADER'=> 'require', 'FILE' => $linker_modulePath . 'lib/lib.' . $linker_component . '.php' );
			include( $linker_modulePath . 'load_includes.php' );

			// saved successfully
			if ( $status == TRUE ):
				if ( array_key_exists( 'savestay', $_POST ) == TRUE ):
					$return_target .= '&action=' . $action . '&link_id=' . $link_id;
				endif;
				if (( isset( $save_anchor )	== TRUE )
				and ( strlen( $save_anchor ) > 0    )):
					$return_target .= '#' . $save_anchor;
				endif;
				$linker_status = $MESSAGE['PAGES']['SAVED'];
			endif;

		else:
			// data manipulation
		// include data manipulation files
		$includes[]	= $linker_modulePath . 'lib/lib.data.php';
		$includes[]	= $linker_templatePath . 'lib/lib.data.php';
		$includes[]	= $linker_modulePath . 'lib/lib.data.' . $linker_component . '.php';
		$includes[]	= $linker_templatePath . 'lib/lib.data.' . $linker_component . '.php';
		include( $linker_modulePath . 'load_includes.php' );

			// twig processing
		// include template engine files
		global $parser, $loader;
		$includes[]	= $linker_modulePath . 'lib/lib.twig.formvalues.php' ;				// initial setting of formvalues
		$includes[]	= $linker_modulePath . 'lib/lib.twig.php' ;						// module specific formvalues
		$includes[]	= $linker_templatePath . 'lib/lib.twig.php' ;						// module specific formvalues
		$includes[]	= $linker_modulePath . 'lib/lib.twig.' . $linker_component . '.php' ;		// component specific formvalues
		$includes[]	= $linker_templatePath . 'lib/lib.twig.' . $linker_component . '.php' ;	// local enhancements of formvalues
		$includes[]	= array( 'LOADER'=> 'require_once', 'FILE' => $linker_modulePath . 'register_parser.php' );
		include( $linker_modulePath . 'load_includes.php' );

		// check if twig template is defined
		if ( isset( $twigTemplate ) == FALSE ):
			// define default twig template
			$twigTemplate =  $linker_component . '.lte';
		endif;

		// process page
		$twig_util->resolve_path( $twigTemplate );

		// buffer output
		if ( isset( $buffer ) == TRUE ):
			// start output buffer
			ob_start();
		endif;

		echo $parser->render(
			$twig_modul_namespace . $twigTemplate,
			$form_values
		);

			// handle return
			$show_success = FALSE;

			// status is always OK
			$status = TRUE;	
		endif;
	endif;

	// or an failure occured
	if ( $status != TRUE ):
		$admin->print_error(
					  $linker_status
					, $return_target
		);
	elseif ( $show_success == TRUE ):
		$admin->print_success(
					  $linker_status
					, $return_target
		);
	endif;

?>
